#
# spec file for package fife
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2011 Nelson Marques <nmarques@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0_4_2
%define oname fifengine
Name:           fife
Version:        0.4.2
Release:        8.5
Summary:        The Flexible Isometric Free Engine, a 2D game engine
License:        LGPL-2.1-or-later
Group:          Amusements/Games/Other
URL:            http://www.fifengine.de
Source:         https://github.com/fifengine/fifengine/archive/%{version}/%{oname}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM swig4.patch -- removed flags that are not supported with swig 4.0
# See https://github.com/fifengine/fifengine/commit/d14f232f4cd9a00b05d6872957070e8c020f515d
Patch0:         swig4.patch
# PATCH-FIX-UPSTREAM
Patch1:         fife-boost_1_77.patch
# PATCH-FIX-UPSTREAM https://github.com/fifengine/fifengine/issues/1085
Patch2:         fife-boost_1_85.patch
BuildRequires:  cmake
BuildRequires:  fifechan-devel
BuildRequires:  gcc-c++
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  swig
BuildRequires:  tinyxml-devel
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} >= 1330
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_system-devel
%else
BuildRequires:  boost-devel
%endif

%description
FIFE stands for Flexible Isometric Free Engine and is a cross platform
game creation framework. It provides the ability to create a
game using Python interfaces.

%package -n libfife%{sover}
Summary:        The Flexible Isometric Free Engine, a 2D game engine
Group:          System/Libraries

%description -n libfife%{sover}
FIFE stands for Flexible Isometric Free Engine and is a cross platform
game creation framework. It provides the ability to create a
game using Python interfaces.

%package -n python3-%{name}
Summary:        Python 3 extensions for the FIFE engine
Group:          Amusements/Games/Other
Requires:       python3

%description -n python3-%{name}
FIFE stands for Flexible Isometric Free Engine and is a cross platform
game creation framework. It provides the ability to create a
game using Python interfaces.

%package devel
Summary:        Development files for the FIFE 2D game engine
Group:          Development/Libraries/Other
Requires:       libfife%{sover} = %{version}
Requires:       python3-fife = %{version}

%description devel
FIFE stands for Flexible Isometric Free Engine and is a cross platform
game creation framework. It provides the ability to create a
game using Python interfaces.

%prep
%setup -q -n %{oname}-%{version}
# only apply the patch if swig 4 is used (currently: Tumbleweed and Leap 15.6)
%if 0%{?suse_version} > 1500 || (0%{?suse_version} == 1500 && 0%{?sle_version} > 150500)
%patch -P 0 -p1
%endif
%patch -P 1 -p1
%patch -P 2 -p1

%build
%define __builddir py3
%cmake \
    -Dbuild-library=ON \
    -Drend-camzone=ON \
    -Drend-grid=ON \
    -Dlibrocket=ON \
    -Dbuild-python=ON \
    -DPYTHON_SITE_PACKAGES=%{python3_sitearch} \
    -DCMAKE_CXX_FLAGS='-DUSE_BOOST_FILESYSTEM_V3'
make VERBOSE=1 %{?_smp_mflags}
cd ..

%install
%define __builddir py3
%cmake_install

# Blocked by https://github.com/fifengine/fifengine/issues/879
# %%check
# export PYTHONPATH="%%{buildroot}%%{python3_sitearch}"
# python3 ./run_tests.py -a

%post -n libfife%{sover} -p /sbin/ldconfig
%postun -n libfife%{sover} -p /sbin/ldconfig

%files -n libfife%{sover}
%if ( 0%{?suse_version} == 1315 && 0%{?sle_version} == 120100 ) || ! 0%{?is_opensuse}
# Leap 42.1 or SLE
%license LICENSE.md
%doc AUTHORS
%else
%license LICENSE.md AUTHORS
%endif
%{_libdir}/*.so.*

%files -n python3-%{name}
%{python3_sitearch}/*

%files devel
%doc CHANGELOG.md README.md
%{_includedir}/fife/
%{_libdir}/*.so

%changelog
* Thu May 16 2024 Dirk Stoecker <opensuse@dstoecker.de>
- fix build with boost 1.85 (fife-boost_1_85.patch)
* Mon May  6 2024 Max Lin <mlin@suse.com>
- Applying swig4.patch on Leap 15.6/SLE15-SP6 too
  * swig 4.1.1 has been added to SLE15-SP6
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Sep 13 2023 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded Requires on python3-future.
* Mon Oct 11 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch:
  * fife-boost_1_77.patch
* Wed Sep 18 2019 Simon Puchert <simonpuchert@alice.de>
- Add swig4.patch: Remove flags that are not supported with swig 4.
* Tue Feb 19 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints file to avoid build failures
* Sun Feb  3 2019 Matthias Bach <marix@marix.org>
- Add missing runtime dependency to python3-futures.
* Sun Jan 13 2019 Jan Engelhardt <jengelh@inai.de>
- Update descriptions.
* Sun Jan 13 2019 Michael Vetter <mvetter@suse.com>
- Enable building share library again (also fixes build)
- Remove project.diff and move content into changes file
* Sun Jan 13 2019 marix@marix.org
- Update to fifengine 0.4.2
  * Compatiblity with fifechan 0.1.5
  * Python bindings are now provided for Python 3
  * Joystick and Gamepad support
- Ship both, Python 3 and Python 2 bindings to not instantly break
  all downstream packages.
- Dropped installation-directories.patch which has been integrated
  upstream.
- Dropped install-rocket-header.patch which has been integrated
  upstream.
- Dropped link-cegui.patch which has been integrated
  upstream.
* Wed Feb 22 2017 rpm@fthiessen.de
- Update to version 0.4.1
- Now build with cmake instead of scons
- Added patches from upstream: install-rocket-header.patch,
  installation-directories.patch and link-cegui.patch
* Sun Jan 11 2015 mailaender@opensuse.org
- FIFE is incompatible with swig version 3
